@@ -1,7 +1,7 @@
 """
 Type annotations for gamesparks service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_gamesparks/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_gamesparks/type_defs/)
 
 Usage::
 
@@ -16,7 +16,6 @@ from datetime import datetime
 from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
-from typing_extensions import NotRequired
 
 from .literals import (
     DeploymentActionType,
@@ -127,20 +126,34 @@ __all__ = (
 ConnectionTypeDef = TypedDict(
     "ConnectionTypeDef",
     {
-        "Created": NotRequired[datetime],
-        "Id": NotRequired[str],
+        "Created": datetime,
+        "Id": str,
     },
+    total=False,
 )
 
-CreateGameRequestRequestTypeDef = TypedDict(
-    "CreateGameRequestRequestTypeDef",
+_RequiredCreateGameRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateGameRequestRequestTypeDef",
     {
         "GameName": str,
-        "ClientToken": NotRequired[str],
-        "Description": NotRequired[str],
-        "Tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateGameRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateGameRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+        "Description": str,
+        "Tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateGameRequestRequestTypeDef(
+    _RequiredCreateGameRequestRequestTypeDef, _OptionalCreateGameRequestRequestTypeDef
+):
+    pass
+
 
 CreateGameResultTypeDef = TypedDict(
     "CreateGameResultTypeDef",
@@ -150,13 +163,26 @@ CreateGameResultTypeDef = TypedDict(
     },
 )
 
-CreateSnapshotRequestRequestTypeDef = TypedDict(
-    "CreateSnapshotRequestRequestTypeDef",
+_RequiredCreateSnapshotRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateSnapshotRequestRequestTypeDef",
     {
         "GameName": str,
-        "Description": NotRequired[str],
     },
 )
+_OptionalCreateSnapshotRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateSnapshotRequestRequestTypeDef",
+    {
+        "Description": str,
+    },
+    total=False,
+)
+
+
+class CreateSnapshotRequestRequestTypeDef(
+    _RequiredCreateSnapshotRequestRequestTypeDef, _OptionalCreateSnapshotRequestRequestTypeDef
+):
+    pass
+
 
 CreateSnapshotResultTypeDef = TypedDict(
     "CreateSnapshotResultTypeDef",
@@ -166,17 +192,30 @@ CreateSnapshotResultTypeDef = TypedDict(
     },
 )
 
-CreateStageRequestRequestTypeDef = TypedDict(
-    "CreateStageRequestRequestTypeDef",
+_RequiredCreateStageRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateStageRequestRequestTypeDef",
     {
         "GameName": str,
         "Role": str,
         "StageName": str,
-        "ClientToken": NotRequired[str],
-        "Description": NotRequired[str],
-        "Tags": NotRequired[Mapping[str, str]],
     },
 )
+_OptionalCreateStageRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateStageRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+        "Description": str,
+        "Tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateStageRequestRequestTypeDef(
+    _RequiredCreateStageRequestRequestTypeDef, _OptionalCreateStageRequestRequestTypeDef
+):
+    pass
+
 
 CreateStageResultTypeDef = TypedDict(
     "CreateStageResultTypeDef",
@@ -238,73 +277,80 @@ ExportSnapshotResultTypeDef = TypedDict(
 ExtensionDetailsTypeDef = TypedDict(
     "ExtensionDetailsTypeDef",
     {
-        "Description": NotRequired[str],
-        "Name": NotRequired[str],
-        "Namespace": NotRequired[str],
+        "Description": str,
+        "Name": str,
+        "Namespace": str,
     },
+    total=False,
 )
 
 ExtensionVersionDetailsTypeDef = TypedDict(
     "ExtensionVersionDetailsTypeDef",
     {
-        "Name": NotRequired[str],
-        "Namespace": NotRequired[str],
-        "Schema": NotRequired[str],
-        "Version": NotRequired[str],
+        "Name": str,
+        "Namespace": str,
+        "Schema": str,
+        "Version": str,
     },
+    total=False,
 )
 
 GameConfigurationDetailsTypeDef = TypedDict(
     "GameConfigurationDetailsTypeDef",
     {
-        "Created": NotRequired[datetime],
-        "LastUpdated": NotRequired[datetime],
-        "Sections": NotRequired[Dict[str, "SectionTypeDef"]],
+        "Created": datetime,
+        "LastUpdated": datetime,
+        "Sections": Dict[str, "SectionTypeDef"],
     },
+    total=False,
 )
 
 GameDetailsTypeDef = TypedDict(
     "GameDetailsTypeDef",
     {
-        "Arn": NotRequired[str],
-        "Created": NotRequired[datetime],
-        "Description": NotRequired[str],
-        "EnableTerminationProtection": NotRequired[bool],
-        "LastUpdated": NotRequired[datetime],
-        "Name": NotRequired[str],
-        "State": NotRequired[GameStateType],
-        "Tags": NotRequired[Dict[str, str]],
+        "Arn": str,
+        "Created": datetime,
+        "Description": str,
+        "EnableTerminationProtection": bool,
+        "LastUpdated": datetime,
+        "Name": str,
+        "State": GameStateType,
+        "Tags": Dict[str, str],
     },
+    total=False,
 )
 
 GameSummaryTypeDef = TypedDict(
     "GameSummaryTypeDef",
     {
-        "Description": NotRequired[str],
-        "Name": NotRequired[str],
-        "State": NotRequired[GameStateType],
-        "Tags": NotRequired[Dict[str, str]],
+        "Description": str,
+        "Name": str,
+        "State": GameStateType,
+        "Tags": Dict[str, str],
     },
+    total=False,
 )
 
 GeneratedCodeJobDetailsTypeDef = TypedDict(
     "GeneratedCodeJobDetailsTypeDef",
     {
-        "Description": NotRequired[str],
-        "ExpirationTime": NotRequired[datetime],
-        "GeneratedCodeJobId": NotRequired[str],
-        "S3Url": NotRequired[str],
-        "Status": NotRequired[GeneratedCodeJobStateType],
+        "Description": str,
+        "ExpirationTime": datetime,
+        "GeneratedCodeJobId": str,
+        "S3Url": str,
+        "Status": GeneratedCodeJobStateType,
     },
+    total=False,
 )
 
 GeneratorTypeDef = TypedDict(
     "GeneratorTypeDef",
     {
-        "GameSdkVersion": NotRequired[str],
-        "Language": NotRequired[str],
-        "TargetPlatform": NotRequired[str],
+        "GameSdkVersion": str,
+        "Language": str,
+        "TargetPlatform": str,
     },
+    total=False,
 )
 
 GetExtensionRequestRequestTypeDef = TypedDict(
@@ -340,13 +386,27 @@ GetExtensionVersionResultTypeDef = TypedDict(
     },
 )
 
-GetGameConfigurationRequestRequestTypeDef = TypedDict(
-    "GetGameConfigurationRequestRequestTypeDef",
+_RequiredGetGameConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredGetGameConfigurationRequestRequestTypeDef",
     {
         "GameName": str,
-        "Sections": NotRequired[Sequence[str]],
     },
 )
+_OptionalGetGameConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalGetGameConfigurationRequestRequestTypeDef",
+    {
+        "Sections": Sequence[str],
+    },
+    total=False,
+)
+
+
+class GetGameConfigurationRequestRequestTypeDef(
+    _RequiredGetGameConfigurationRequestRequestTypeDef,
+    _OptionalGetGameConfigurationRequestRequestTypeDef,
+):
+    pass
+
 
 GetGameConfigurationResultTypeDef = TypedDict(
     "GetGameConfigurationResultTypeDef",
@@ -405,14 +465,27 @@ GetPlayerConnectionStatusResultTypeDef = TypedDict(
     },
 )
 
-GetSnapshotRequestRequestTypeDef = TypedDict(
-    "GetSnapshotRequestRequestTypeDef",
+_RequiredGetSnapshotRequestRequestTypeDef = TypedDict(
+    "_RequiredGetSnapshotRequestRequestTypeDef",
     {
         "GameName": str,
         "SnapshotId": str,
-        "Sections": NotRequired[Sequence[str]],
     },
 )
+_OptionalGetSnapshotRequestRequestTypeDef = TypedDict(
+    "_OptionalGetSnapshotRequestRequestTypeDef",
+    {
+        "Sections": Sequence[str],
+    },
+    total=False,
+)
+
+
+class GetSnapshotRequestRequestTypeDef(
+    _RequiredGetSnapshotRequestRequestTypeDef, _OptionalGetSnapshotRequestRequestTypeDef
+):
+    pass
+
 
 GetSnapshotResultTypeDef = TypedDict(
     "GetSnapshotResultTypeDef",
@@ -422,14 +495,28 @@ GetSnapshotResultTypeDef = TypedDict(
     },
 )
 
-GetStageDeploymentRequestRequestTypeDef = TypedDict(
-    "GetStageDeploymentRequestRequestTypeDef",
+_RequiredGetStageDeploymentRequestRequestTypeDef = TypedDict(
+    "_RequiredGetStageDeploymentRequestRequestTypeDef",
     {
         "GameName": str,
         "StageName": str,
-        "DeploymentId": NotRequired[str],
     },
 )
+_OptionalGetStageDeploymentRequestRequestTypeDef = TypedDict(
+    "_OptionalGetStageDeploymentRequestRequestTypeDef",
+    {
+        "DeploymentId": str,
+    },
+    total=False,
+)
+
+
+class GetStageDeploymentRequestRequestTypeDef(
+    _RequiredGetStageDeploymentRequestRequestTypeDef,
+    _OptionalGetStageDeploymentRequestRequestTypeDef,
+):
+    pass
+
 
 GetStageDeploymentResultTypeDef = TypedDict(
     "GetStageDeploymentResultTypeDef",
@@ -474,28 +561,56 @@ ImportGameConfigurationResultTypeDef = TypedDict(
 ImportGameConfigurationSourceTypeDef = TypedDict(
     "ImportGameConfigurationSourceTypeDef",
     {
-        "File": Union[bytes, IO[bytes], StreamingBody],
+        "File": Union[str, bytes, IO[Any], StreamingBody],
     },
 )
 
-ListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef = TypedDict(
-    "ListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef",
+_RequiredListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef = TypedDict(
+    "_RequiredListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef",
     {
         "Name": str,
         "Namespace": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef = TypedDict(
+    "_OptionalListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListExtensionVersionsRequestRequestTypeDef = TypedDict(
-    "ListExtensionVersionsRequestRequestTypeDef",
+
+class ListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef(
+    _RequiredListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef,
+    _OptionalListExtensionVersionsRequestListExtensionVersionsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListExtensionVersionsRequestRequestTypeDef = TypedDict(
+    "_RequiredListExtensionVersionsRequestRequestTypeDef",
     {
         "Name": str,
         "Namespace": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListExtensionVersionsRequestRequestTypeDef = TypedDict(
+    "_OptionalListExtensionVersionsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListExtensionVersionsRequestRequestTypeDef(
+    _RequiredListExtensionVersionsRequestRequestTypeDef,
+    _OptionalListExtensionVersionsRequestRequestTypeDef,
+):
+    pass
+
 
 ListExtensionVersionsResultTypeDef = TypedDict(
     "ListExtensionVersionsResultTypeDef",
@@ -509,16 +624,18 @@ ListExtensionVersionsResultTypeDef = TypedDict(
 ListExtensionsRequestListExtensionsPaginateTypeDef = TypedDict(
     "ListExtensionsRequestListExtensionsPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListExtensionsRequestRequestTypeDef = TypedDict(
     "ListExtensionsRequestRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListExtensionsResultTypeDef = TypedDict(
@@ -533,16 +650,18 @@ ListExtensionsResultTypeDef = TypedDict(
 ListGamesRequestListGamesPaginateTypeDef = TypedDict(
     "ListGamesRequestListGamesPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListGamesRequestRequestTypeDef = TypedDict(
     "ListGamesRequestRequestTypeDef",
     {
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
+        "MaxResults": int,
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListGamesResultTypeDef = TypedDict(
@@ -554,24 +673,52 @@ ListGamesResultTypeDef = TypedDict(
     },
 )
 
-ListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef = TypedDict(
-    "ListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef",
+_RequiredListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef = TypedDict(
+    "_RequiredListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef",
     {
         "GameName": str,
         "SnapshotId": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef = TypedDict(
+    "_OptionalListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListGeneratedCodeJobsRequestRequestTypeDef = TypedDict(
-    "ListGeneratedCodeJobsRequestRequestTypeDef",
+
+class ListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef(
+    _RequiredListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef,
+    _OptionalListGeneratedCodeJobsRequestListGeneratedCodeJobsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListGeneratedCodeJobsRequestRequestTypeDef = TypedDict(
+    "_RequiredListGeneratedCodeJobsRequestRequestTypeDef",
     {
         "GameName": str,
         "SnapshotId": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListGeneratedCodeJobsRequestRequestTypeDef = TypedDict(
+    "_OptionalListGeneratedCodeJobsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListGeneratedCodeJobsRequestRequestTypeDef(
+    _RequiredListGeneratedCodeJobsRequestRequestTypeDef,
+    _OptionalListGeneratedCodeJobsRequestRequestTypeDef,
+):
+    pass
+
 
 ListGeneratedCodeJobsResultTypeDef = TypedDict(
     "ListGeneratedCodeJobsResultTypeDef",
@@ -582,22 +729,49 @@ ListGeneratedCodeJobsResultTypeDef = TypedDict(
     },
 )
 
-ListSnapshotsRequestListSnapshotsPaginateTypeDef = TypedDict(
-    "ListSnapshotsRequestListSnapshotsPaginateTypeDef",
+_RequiredListSnapshotsRequestListSnapshotsPaginateTypeDef = TypedDict(
+    "_RequiredListSnapshotsRequestListSnapshotsPaginateTypeDef",
     {
         "GameName": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListSnapshotsRequestListSnapshotsPaginateTypeDef = TypedDict(
+    "_OptionalListSnapshotsRequestListSnapshotsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListSnapshotsRequestRequestTypeDef = TypedDict(
-    "ListSnapshotsRequestRequestTypeDef",
+
+class ListSnapshotsRequestListSnapshotsPaginateTypeDef(
+    _RequiredListSnapshotsRequestListSnapshotsPaginateTypeDef,
+    _OptionalListSnapshotsRequestListSnapshotsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListSnapshotsRequestRequestTypeDef = TypedDict(
+    "_RequiredListSnapshotsRequestRequestTypeDef",
     {
         "GameName": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListSnapshotsRequestRequestTypeDef = TypedDict(
+    "_OptionalListSnapshotsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListSnapshotsRequestRequestTypeDef(
+    _RequiredListSnapshotsRequestRequestTypeDef, _OptionalListSnapshotsRequestRequestTypeDef
+):
+    pass
+
 
 ListSnapshotsResultTypeDef = TypedDict(
     "ListSnapshotsResultTypeDef",
@@ -608,24 +782,52 @@ ListSnapshotsResultTypeDef = TypedDict(
     },
 )
 
-ListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef = TypedDict(
-    "ListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef",
+_RequiredListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef = TypedDict(
+    "_RequiredListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef",
     {
         "GameName": str,
         "StageName": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef = TypedDict(
+    "_OptionalListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListStageDeploymentsRequestRequestTypeDef = TypedDict(
-    "ListStageDeploymentsRequestRequestTypeDef",
+
+class ListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef(
+    _RequiredListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef,
+    _OptionalListStageDeploymentsRequestListStageDeploymentsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListStageDeploymentsRequestRequestTypeDef = TypedDict(
+    "_RequiredListStageDeploymentsRequestRequestTypeDef",
     {
         "GameName": str,
         "StageName": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListStageDeploymentsRequestRequestTypeDef = TypedDict(
+    "_OptionalListStageDeploymentsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListStageDeploymentsRequestRequestTypeDef(
+    _RequiredListStageDeploymentsRequestRequestTypeDef,
+    _OptionalListStageDeploymentsRequestRequestTypeDef,
+):
+    pass
+
 
 ListStageDeploymentsResultTypeDef = TypedDict(
     "ListStageDeploymentsResultTypeDef",
@@ -636,22 +838,49 @@ ListStageDeploymentsResultTypeDef = TypedDict(
     },
 )
 
-ListStagesRequestListStagesPaginateTypeDef = TypedDict(
-    "ListStagesRequestListStagesPaginateTypeDef",
+_RequiredListStagesRequestListStagesPaginateTypeDef = TypedDict(
+    "_RequiredListStagesRequestListStagesPaginateTypeDef",
     {
         "GameName": str,
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalListStagesRequestListStagesPaginateTypeDef = TypedDict(
+    "_OptionalListStagesRequestListStagesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-ListStagesRequestRequestTypeDef = TypedDict(
-    "ListStagesRequestRequestTypeDef",
+
+class ListStagesRequestListStagesPaginateTypeDef(
+    _RequiredListStagesRequestListStagesPaginateTypeDef,
+    _OptionalListStagesRequestListStagesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListStagesRequestRequestTypeDef = TypedDict(
+    "_RequiredListStagesRequestRequestTypeDef",
     {
         "GameName": str,
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
     },
 )
+_OptionalListStagesRequestRequestTypeDef = TypedDict(
+    "_OptionalListStagesRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListStagesRequestRequestTypeDef(
+    _RequiredListStagesRequestRequestTypeDef, _OptionalListStagesRequestRequestTypeDef
+):
+    pass
+
 
 ListStagesResultTypeDef = TypedDict(
     "ListStagesResultTypeDef",
@@ -680,10 +909,11 @@ ListTagsForResourceResultTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -697,94 +927,114 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-SectionModificationTypeDef = TypedDict(
-    "SectionModificationTypeDef",
+_RequiredSectionModificationTypeDef = TypedDict(
+    "_RequiredSectionModificationTypeDef",
     {
         "Operation": OperationType,
         "Path": str,
         "Section": str,
-        "Value": NotRequired[Mapping[str, Any]],
     },
 )
+_OptionalSectionModificationTypeDef = TypedDict(
+    "_OptionalSectionModificationTypeDef",
+    {
+        "Value": Mapping[str, Any],
+    },
+    total=False,
+)
+
+
+class SectionModificationTypeDef(
+    _RequiredSectionModificationTypeDef, _OptionalSectionModificationTypeDef
+):
+    pass
+
 
 SectionTypeDef = TypedDict(
     "SectionTypeDef",
     {
-        "Attributes": NotRequired[Dict[str, Any]],
-        "Name": NotRequired[str],
-        "Size": NotRequired[int],
+        "Attributes": Dict[str, Any],
+        "Name": str,
+        "Size": int,
     },
+    total=False,
 )
 
 SnapshotDetailsTypeDef = TypedDict(
     "SnapshotDetailsTypeDef",
     {
-        "Created": NotRequired[datetime],
-        "Description": NotRequired[str],
-        "Id": NotRequired[str],
-        "LastUpdated": NotRequired[datetime],
-        "Sections": NotRequired[Dict[str, "SectionTypeDef"]],
+        "Created": datetime,
+        "Description": str,
+        "Id": str,
+        "LastUpdated": datetime,
+        "Sections": Dict[str, "SectionTypeDef"],
     },
+    total=False,
 )
 
 SnapshotSummaryTypeDef = TypedDict(
     "SnapshotSummaryTypeDef",
     {
-        "Created": NotRequired[datetime],
-        "Description": NotRequired[str],
-        "Id": NotRequired[str],
-        "LastUpdated": NotRequired[datetime],
+        "Created": datetime,
+        "Description": str,
+        "Id": str,
+        "LastUpdated": datetime,
     },
+    total=False,
 )
 
 StageDeploymentDetailsTypeDef = TypedDict(
     "StageDeploymentDetailsTypeDef",
     {
-        "Created": NotRequired[datetime],
-        "DeploymentAction": NotRequired[DeploymentActionType],
-        "DeploymentId": NotRequired[str],
-        "DeploymentState": NotRequired[DeploymentStateType],
-        "LastUpdated": NotRequired[datetime],
-        "SnapshotId": NotRequired[str],
+        "Created": datetime,
+        "DeploymentAction": DeploymentActionType,
+        "DeploymentId": str,
+        "DeploymentState": DeploymentStateType,
+        "LastUpdated": datetime,
+        "SnapshotId": str,
     },
+    total=False,
 )
 
 StageDeploymentSummaryTypeDef = TypedDict(
     "StageDeploymentSummaryTypeDef",
     {
-        "DeploymentAction": NotRequired[DeploymentActionType],
-        "DeploymentId": NotRequired[str],
-        "DeploymentState": NotRequired[DeploymentStateType],
-        "LastUpdated": NotRequired[datetime],
-        "SnapshotId": NotRequired[str],
+        "DeploymentAction": DeploymentActionType,
+        "DeploymentId": str,
+        "DeploymentState": DeploymentStateType,
+        "LastUpdated": datetime,
+        "SnapshotId": str,
     },
+    total=False,
 )
 
 StageDetailsTypeDef = TypedDict(
     "StageDetailsTypeDef",
     {
-        "Arn": NotRequired[str],
-        "Created": NotRequired[datetime],
-        "Description": NotRequired[str],
-        "GameKey": NotRequired[str],
-        "LastUpdated": NotRequired[datetime],
-        "LogGroup": NotRequired[str],
-        "Name": NotRequired[str],
-        "Role": NotRequired[str],
-        "State": NotRequired[StageStateType],
-        "Tags": NotRequired[Dict[str, str]],
+        "Arn": str,
+        "Created": datetime,
+        "Description": str,
+        "GameKey": str,
+        "LastUpdated": datetime,
+        "LogGroup": str,
+        "Name": str,
+        "Role": str,
+        "State": StageStateType,
+        "Tags": Dict[str, str],
     },
+    total=False,
 )
 
 StageSummaryTypeDef = TypedDict(
     "StageSummaryTypeDef",
     {
-        "Description": NotRequired[str],
-        "GameKey": NotRequired[str],
-        "Name": NotRequired[str],
-        "State": NotRequired[StageStateType],
-        "Tags": NotRequired[Dict[str, str]],
+        "Description": str,
+        "GameKey": str,
+        "Name": str,
+        "State": StageStateType,
+        "Tags": Dict[str, str],
     },
+    total=False,
 )
 
 StartGeneratedCodeJobRequestRequestTypeDef = TypedDict(
@@ -804,15 +1054,29 @@ StartGeneratedCodeJobResultTypeDef = TypedDict(
     },
 )
 
-StartStageDeploymentRequestRequestTypeDef = TypedDict(
-    "StartStageDeploymentRequestRequestTypeDef",
+_RequiredStartStageDeploymentRequestRequestTypeDef = TypedDict(
+    "_RequiredStartStageDeploymentRequestRequestTypeDef",
     {
         "GameName": str,
         "SnapshotId": str,
         "StageName": str,
-        "ClientToken": NotRequired[str],
     },
 )
+_OptionalStartStageDeploymentRequestRequestTypeDef = TypedDict(
+    "_OptionalStartStageDeploymentRequestRequestTypeDef",
+    {
+        "ClientToken": str,
+    },
+    total=False,
+)
+
+
+class StartStageDeploymentRequestRequestTypeDef(
+    _RequiredStartStageDeploymentRequestRequestTypeDef,
+    _OptionalStartStageDeploymentRequestRequestTypeDef,
+):
+    pass
+
 
 StartStageDeploymentResultTypeDef = TypedDict(
     "StartStageDeploymentResultTypeDef",
@@ -854,13 +1118,26 @@ UpdateGameConfigurationResultTypeDef = TypedDict(
     },
 )
 
-UpdateGameRequestRequestTypeDef = TypedDict(
-    "UpdateGameRequestRequestTypeDef",
+_RequiredUpdateGameRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateGameRequestRequestTypeDef",
     {
         "GameName": str,
-        "Description": NotRequired[str],
     },
 )
+_OptionalUpdateGameRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateGameRequestRequestTypeDef",
+    {
+        "Description": str,
+    },
+    total=False,
+)
+
+
+class UpdateGameRequestRequestTypeDef(
+    _RequiredUpdateGameRequestRequestTypeDef, _OptionalUpdateGameRequestRequestTypeDef
+):
+    pass
+
 
 UpdateGameResultTypeDef = TypedDict(
     "UpdateGameResultTypeDef",
@@ -870,14 +1147,27 @@ UpdateGameResultTypeDef = TypedDict(
     },
 )
 
-UpdateSnapshotRequestRequestTypeDef = TypedDict(
-    "UpdateSnapshotRequestRequestTypeDef",
+_RequiredUpdateSnapshotRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateSnapshotRequestRequestTypeDef",
     {
         "GameName": str,
         "SnapshotId": str,
-        "Description": NotRequired[str],
     },
 )
+_OptionalUpdateSnapshotRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateSnapshotRequestRequestTypeDef",
+    {
+        "Description": str,
+    },
+    total=False,
+)
+
+
+class UpdateSnapshotRequestRequestTypeDef(
+    _RequiredUpdateSnapshotRequestRequestTypeDef, _OptionalUpdateSnapshotRequestRequestTypeDef
+):
+    pass
+
 
 UpdateSnapshotResultTypeDef = TypedDict(
     "UpdateSnapshotResultTypeDef",
@@ -887,15 +1177,28 @@ UpdateSnapshotResultTypeDef = TypedDict(
     },
 )
 
-UpdateStageRequestRequestTypeDef = TypedDict(
-    "UpdateStageRequestRequestTypeDef",
+_RequiredUpdateStageRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateStageRequestRequestTypeDef",
     {
         "GameName": str,
         "StageName": str,
-        "Description": NotRequired[str],
-        "Role": NotRequired[str],
     },
 )
+_OptionalUpdateStageRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateStageRequestRequestTypeDef",
+    {
+        "Description": str,
+        "Role": str,
+    },
+    total=False,
+)
+
+
+class UpdateStageRequestRequestTypeDef(
+    _RequiredUpdateStageRequestRequestTypeDef, _OptionalUpdateStageRequestRequestTypeDef
+):
+    pass
+
 
 UpdateStageResultTypeDef = TypedDict(
     "UpdateStageResultTypeDef",
